certlin: SageMath package for linear inequality systems and certifying (un)solvability
======================================================================================

Description
-----------

SageMath package for linear inequality systems and certifying (un)solvability

License
-------

GPL-3.0-or-later

Upstream Contact
----------------

https://pypi.org/project/certlin/

